@@ -1,15 +1,12 @@
 import circle
 from circle.resources.ach import Ach
+from circle.resources.balances import Balances
 from circle.resources.card import Card
 from circle.resources.error_object import ErrorObject
 from circle.resources.master_wallet import MasterWallet
 from circle.resources.message import Message
+from circle.resources.mock_wire_payment import MockWirePayment
 from circle.resources.mocks_ach_account import MocksAchAccount
-
-if circle.api_base == "https://api-sandbox.circle.com":
-    # Only import MockWirePayment in the sandbox environment
-    from circle.resources.mock_wire_payment import MockWirePayment
-
 from circle.resources.notification import Notification
 from circle.resources.payment import Payment
 from circle.resources.payout import Payout
