@@ -12,7 +12,7 @@ class APIResource(CircleObject):
     def class_url(cls):
         if cls == APIResource:
             raise NotImplementedError(
-                "APIResource is an abstract class. Perform actions on one of its subsclasses (e.g. Charge)."
+                "APIResource is an abstract class. Perform actions on one of its subclasses (e.g. Card)."
             )
 
         base = cls.OBJECT_NAME.replace(".", "/")
